@@ -1,7 +1,7 @@
 package Log::Any::For::Builtins;
 
-our $DATE = '2016-04-17'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-04-18'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,11 +38,12 @@ sub readpipe {
         $log->tracef("readpipe() child error: %d (%s)",
                      $?, explain_child_error()) if $?;
         if ($wa) { $output = join("", @output) }
+        my $len = length($output // '');
         $log->tracef("readpipe() output (%d bytes%s): %s",
-                     length($output),
-                     (length($output) > $Max_Log_Output ?
+                     $len,
+                     ($len > $Max_Log_Output ?
                          ", $Max_Log_Output shown" : ""),
-                     ellipsis($output, $Max_Log_Output+3));
+                     ellipsis($output // '', $Max_Log_Output+3));
     }
     $wa ? @output : $output;
 }
@@ -82,7 +83,7 @@ Log::Any::For::Builtins - (DEPRECATED) Log builtin functions
 
 =head1 VERSION
 
-This document describes version 0.12 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2016-04-17.
+This document describes version 0.13 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2016-04-18.
 
 =head1 SYNOPSIS
 
